#
#  Name:    MpScan.py
#
#  Purpose: This Python module implements some utility functions for
#           manipulating MX scans.
#
#           The module assumes that Python functions named 'log_print'
#           and 'error_dialog' have already been defined in the current
#           namespace.  They are expected to have prototypes like
#
#               log_print( output_string )
#               error_dialog( title_bar_string, dialog_string )
#
#  Author:  William Lavender
#
#-----------------------------------------------------------------------
#
#  Copyright 2002 Illinois Institute of Technology
#
#  See the file "LICENSE" for information on usage and redistribution
#  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#

#
#  Load a file of scan records into the current database.
#

def load_scans( record_list, filename, initialize_flag ):

	log_print( "Reading database '%s'" % ( filename ) )

	try:
		file = open( filename, "r" )
	except:
		error_dialog( "Error Opening File", \
			"Cannot read old scan database file '%s'" % filename )
		return

	while ( 1 ):

		### Read in a record description. ###

		try:
			description = file.readline()
		except:
			log_print( "Error reading description." )
			break

		### If we are at EOF, exit the while loop. ###

		if ( len( description ) == 0 ):
			break

		### What is the name of the record we are trying to create? ###

		description_list = split( description )
		record_name = description_list[0]

		### Does a record by this name already exist? ###

		continue_statement = 0	# This is bogus.

		try:
			old_record = record_list.get_record( record_name )

			### Is the old record a scan record? ###

			superclass = old_record.get_field( "mx_superclass" )

			### If so delete it, otherwise skip it. ###

			if ( superclass == "scan" ):
				old_record.delete_record()
			else:
				t = "Skipping scan '%s' from file '%s'.  "
				t = t + "Only preexisting records that are "
				t = t + "scan records may be replaced."

				log_print( t % ( record_name, filename ) )

				continue_statement = 1	# This is also bogus.
		except:
			pass

		### The following offense against nature is due to the fact
		### that Python does not allow 'continue' inside a try
		### statement.  A footnote in Python's language reference
		### manual says that this restriction is due to the
		### "implementer's laziness" (!?!?!!!)
		### ( Insert unprintable comment here. )

		if ( continue_statement ):
			continue

		### Now create the record. ###

		try:
			new_record = \
		record_list.create_record_from_description( description )

		except:
			log_print( "Error creating record '%s'" % record_name )
			file.close()
			return

		try:
			new_record.finish_record_initialization()
		except:
			log_print( \
				"Error initializing record '%s'" % record_name )
			file.close()
			return

	### We are done so close the file. ###

	file.close()

	log_print( "Database successfully read." )

#
#  Save all the scans in the current database to a file.
#

def save_scans( record_list, filename ):

	try:
		file = open( filename, "w" )
	except:
		error_dialog( "Error Opening File", \
			"Cannot write to scan database file '%s'" % filename )
		return

	log_print( "Writing database '%s'" % filename )

	### Get the list head record.  It is called 'mx_database'. ###

	try:
		list_head_record = record_list.get_record( "mx_database" )
	except:
		t = "The 'record_list' object passed to 'save_scans' "
		t = t + "is not a valid Mp.RecordList.  "
		t = t + "This is probably due to an error in the program "
		t = t + "that called 'save_scans'."

		error_dialog( "Wrong Object Type", t )
		return

	### Loop through the current database looking for scan records. ###

	current_record = list_head_record.get_next_record()

	while ( current_record is not list_head_record ):

		superclass = current_record.get_field( "mx_superclass" )

		if ( superclass == "scan" ):
			description = \
				current_record.create_description_from_record()

			file.write( description )

		current_record = current_record.get_next_record()

	file.close()

	record_list._unsaved_scans = 0

	log_print( "Database successfully written." )

