/*
 * Name:    mptk_output.c
 *
 * Purpose: Python output handlers for the MX message log window.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2002 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include "Python.h"

#include "mx_util.h"

#include "mptk.h"

static void MpTkPrivate_generic_output_handler( char * );

static void MpTkPrivate_info_dialog_handler( char *, char *, char * );

MX_EXPORT PyObject *
MpTkPrivate_install_output_handlers_cmd( PyObject *self, PyObject *args )
{
	mx_set_info_output_function( MpTkPrivate_generic_output_handler );
	mx_set_warning_output_function( MpTkPrivate_generic_output_handler );
	mx_set_error_output_function( MpTkPrivate_generic_output_handler );
	mx_set_debug_output_function( MpTkPrivate_generic_output_handler );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpTkPrivate_install_dialog_handler_cmd( PyObject *self, PyObject *args )
{
	mx_set_info_dialog_function( MpTkPrivate_info_dialog_handler );

	Py_INCREF(Py_None);

	return Py_None;
}

static void
MpTkPrivate_generic_output_handler( char *output )
{
	char command[1024];

	/* MpTk._log_window is assumed to be a ScrolledText window.
	 * This window must already have been set up before this 
	 * function is called.
	 */

	sprintf( command,
		"MpTk._log_window.insert(END, %s); "
		"MpTk._log_window.yview_moveto(1.0)",
		output );

	(void) PyRun_SimpleString( command );

	/* Allow some Tkinter events to be processed. */

	MpTkPrivate_process_tkinter_events();

	return;
}

static void
MpTkPrivate_info_dialog_handler( char *text_prompt, char *gui_prompt,
						char *button_text )
{
	char command[400];

	sprintf( command,
		"tkMessageBox.showinfo(\"MX Info\",\"%s\")",
		gui_prompt );

	(void) PyRun_SimpleString( command );

	return;
}

